@@ -5,6 +5,7 @@
 namespace Icinga\Module\Cube;
 
 use Icinga\Web\Url;
+use ipl\Stdlib\Str;
 
 class DimensionParams
 {
@@ -18,7 +19,6 @@ class DimensionParams
      */
     protected $params;
 
-    // For the form: DimensionsParam::fromUrl($url)
     public static function fromUrl(Url $url)
     {
         return static::fromString($url->getParam('dimensions'));
@@ -33,13 +33,11 @@ class DimensionParams
         return $self;
     }
 
-    // For the controller: DimensionsParam::fromArray($this->params->shift('dimensions'))
     public static function fromString($dimensions)
     {
-        return static::fromArray(explode(',', $dimensions));
+        return static::fromArray(Str::trimSplit($dimensions));
     }
 
-
     /**
      * @param $dimension
      *
@@ -59,11 +57,11 @@ class DimensionParams
      *
      * @param $dimensions
      *
-     * @return $this
+     * @return DimensionParams
      */
     public static function update($dimensions)
     {
-        $self =  new static();
+        $self = new static();
         $self->dimensions = $dimensions;
 
         return $self;
