@@ -4,9 +4,8 @@ namespace Icinga\Module\Cube\ProvidedHook\Cube;
 
 use Icinga\Module\Cube\Hook\IcingaDbActionsHook;
 use Icinga\Module\Cube\IcingaDb\IcingaDbCube;
-use Icinga\Module\Cube\Icingadb\IcingadbServiceStatusCube;
+use Icinga\Module\Cube\IcingaDb\IcingaDbServiceStatusCube;
 use ipl\Stdlib\Filter;
-use ipl\Web\Filter\QueryString;
 use ipl\Web\Url;
 
 class IcingaDbActions extends IcingaDbActionsHook
@@ -14,7 +13,7 @@ class IcingaDbActions extends IcingaDbActionsHook
     public function createActionLinks(IcingaDbCube $cube)
     {
         $type = 'host';
-        if ($cube instanceof IcingadbServiceStatusCube) {
+        if ($cube instanceof IcingaDbServiceStatusCube) {
             $type = 'service';
         }
 
@@ -28,7 +27,7 @@ class IcingaDbActions extends IcingaDbActionsHook
         }
 
         $url = Url::fromPath('icingadb/' . $type . 's');
-        $url->setQueryString(QueryString::render($filter));
+        $url->setFilter($filter);
 
         if ($type === 'host') {
             $this->addActionLink(
